==> eam-wshub-proxyclient-11.4-0-sources.jar: net/datastream/schemas/mp_fields/GRIDFIELDBOILERTEXTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for GRIDFIELDBOILERTEXTID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="GRIDFIELDBOILERTEXTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BOILERTEXTENTRIESID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}GRIDFIELDLABEL"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "GRIDFIELDBOILERTEXTID_Type", propOrder = {
    "boilertextentriesid",
    "gridfieldlabel"
})
public class GRIDFIELDBOILERTEXTID_Type {

    @XmlElement(name = "BOILERTEXTENTRIESID", required = true)
    protected BOILERTEXTENTRIESID_Type boilertextentriesid;
    @XmlElement(name = "GRIDFIELDLABEL", required = true)
    protected String gridfieldlabel;

    /**
     * Gets the value of the boilertextentriesid property.
     * 
     * @return
     *     possible object is
     *     {@link BOILERTEXTENTRIESID_Type }
     *     
     */
    public BOILERTEXTENTRIESID_Type getBOILERTEXTENTRIESID() {
        return boilertextentriesid;
    }

    /**
     * Sets the value of the boilertextentriesid property.
     * 
     * @param value
     *     allowed object is
     *     {@link BOILERTEXTENTRIESID_Type }
     *     
     */
    public void setBOILERTEXTENTRIESID(BOILERTEXTENTRIESID_Type value) {
        this.boilertextentriesid = value;
    }

    /**
     * Gets the value of the gridfieldlabel property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGRIDFIELDLABEL() {
        return gridfieldlabel;
    }

    /**
     * Sets the value of the gridfieldlabel property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGRIDFIELDLABEL(String value) {
        this.gridfieldlabel = value;
    }

}

==> eam-wshub-proxyclient-11.4-7-sources.jar: net/datastream/schemas/mp_fields/GRIDFIELDBOILERTEXTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour GRIDFIELDBOILERTEXTID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="GRIDFIELDBOILERTEXTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BOILERTEXTENTRIESID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}GRIDFIELDLABEL"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "GRIDFIELDBOILERTEXTID_Type", propOrder = {
    "boilertextentriesid",
    "gridfieldlabel"
})
public class GRIDFIELDBOILERTEXTID_Type {

    @XmlElement(name = "BOILERTEXTENTRIESID", required = true)
    protected BOILERTEXTENTRIESID_Type boilertextentriesid;
    @XmlElement(name = "GRIDFIELDLABEL", required = true)
    protected String gridfieldlabel;

    /**
     * Obtient la valeur de la propriété boilertextentriesid.
     * 
     * @return
     *     possible object is
     *     {@link BOILERTEXTENTRIESID_Type }
     *     
     */
    public BOILERTEXTENTRIESID_Type getBOILERTEXTENTRIESID() {
        return boilertextentriesid;
    }

    /**
     * Définit la valeur de la propriété boilertextentriesid.
     * 
     * @param value
     *     allowed object is
     *     {@link BOILERTEXTENTRIESID_Type }
     *     
     */
    public void setBOILERTEXTENTRIESID(BOILERTEXTENTRIESID_Type value) {
        this.boilertextentriesid = value;
    }

    /**
     * Obtient la valeur de la propriété gridfieldlabel.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGRIDFIELDLABEL() {
        return gridfieldlabel;
    }

    /**
     * Définit la valeur de la propriété gridfieldlabel.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGRIDFIELDLABEL(String value) {
        this.gridfieldlabel = value;
    }

}
